@@ -40,48 +40,65 @@
 #' Statistical Significance Estimation. PLoS Computational Biology, 4(5).
 #' 
 #' @note The HMMER3 software must be installed on the system for this function to work, i.e. the command
-#' \samp{system("hmmscan")} must be recognized as a valid command if you run it in the Console window.
+#' \samp{system("hmmscan -h")} must be recognized as a valid command if you run it in the Console window.
 #' 
 #' @author Lars Snipen and Kristian Hovde Liland.
 #' 
 #' @seealso \code{\link{panPrep}}, \code{\link{readHmmer}}.
 #' 
-#' @examples 
+#' @examples
 #' \dontrun{
-#' # Using a FASTA file in the micropan package
-#' # We need to uncompress it first...
-#' extdata.path <- file.path(path.package("micropan"),"extdata")
-#' filenames <- "Mpneumoniae_309_GID2.fsa"
-#' pth <- lapply( file.path( extdata.path, paste( filenames, ".xz", sep="" ) ), xzuncompress )
+#' # This example requires the external HMMER software
+#' # Using two files in the micropan package
+#' xpth <- file.path(path.package("micropan"),"extdata")
+#' prot.file <- file.path(xpth,"Example_proteins_GID1.fasta.xz")
+#' db <- "microfam.hmm"
+#' db.files <- file.path(xpth,paste(db,c(".h3f.xz",".h3i.xz",".h3m.xz",".h3p.xz"),sep=""))
 #' 
-#' # Using a miniature pHMM database in the micropan package
-#' # We need to uncompress its datafiles first...
-#' db <- "microfam0.hmm"
-#' pth <- lapply( file.path( extdata.path,
-#'    paste( db, c(".h3f.xz",".h3i.xz",".h3m.xz",".h3p.xz"), sep="" ) ), xzuncompress )
-#'   
-#' # ...and scanning the FASTA-file against microfam0...
-#' hmmerScan(in.files=file.path(extdata.path,filenames), 
-#'    db=file.path(extdata.path,db),out.folder=".")
-#'   
-#' # ...and compressing all files again...
-#' pth <- lapply( file.path( extdata.path, filenames ), xzcompress )
-#' pth <- lapply( file.path( extdata.path,
-#'    paste( db, c(".h3f",".h3i",".h3m",".h3p"), sep="" ) ), xzcompress )
+#' # We need to uncompress them first...
+#' prot.tf <- tempfile(pattern="GID1.fasta",fileext=".xz")
+#' s <- file.copy(prot.file,prot.tf)
+#' prot.tf <- xzuncompress(prot.tf)
+#' db.tf <- paste(tempfile(),c(".h3f.xz",".h3i.xz",".h3m.xz",".h3p.xz"),sep="")
+#' s <- file.copy(db.files,db.tf)
+#' db.tf <- unlist(lapply(db.tf,xzuncompress))
+#' db.name <- gsub("\\",.Platform$file.sep,sub(".h3f$","",db.tf[1]),fixed=T)
+#' 
+#' # Scanning the FASTA-file against microfam0...
+#' tmp.dir <- tempdir()
+#' hmmerScan(in.files=prot.tf,db=db.name,out.folder=tmp.dir)
+#'
+#' # Reading results
+#' db.nm <- rev(unlist(strsplit(db.name,split=.Platform$file.sep)))[1]
+#' hmm.file <- file.path(tmp.dir,paste("GID1_vs_",db.nm,".txt",sep=""))
+#' hmm.tab <- readHmmer(hmm.file)
+#' 
+#' # ...and cleaning...
+#' s <- file.remove(prot.tf)
+#' s <- file.remove(sub(".xz","",db.tf))
+#' s <- file.remove(hmm.file)
 #' }
 #' 
-#' @export
+#' @export hmmerScan
+#' 
 hmmerScan <- function( in.files, db, out.folder, threads=0, verbose=TRUE ){
-  basic <- paste( "hmmscan -o hmmer3.txt --cut_ga --noali --domtblout --cpu", threads )
-  db.name <- rev( unlist( strsplit( db, split="/" ) ) )[1]
-  for( i in 1:length( in.files ) ){
-    gi <- gregexpr( "GID[0-9]+", in.files[i], extract=T )
-    rname <- paste( gi, "_vs_", db.name, ".txt", sep="" )
-    res.files <- dir( out.folder )
-    if( !(rname %in% res.files) ){
-      if( verbose ) cat( "hmmerScan: Scanning", in.files[i], "...\n" )
-      command <- paste( basic, file.path( out.folder, rname ), db, in.files[i]  )
-      system( command )
+  if( length(db)>1 ){
+    stop( "Argument db must be a single text" )
+  }
+  if( available.external( "hmmer" ) ){
+    log.fil <- file.path( out.folder, "log.txt" )
+    basic <- paste( "hmmscan -o", log.fil,"--cut_ga --noali --cpu", threads )
+    db.name <- rev( unlist( strsplit( db, split=.Platform$file.sep ) ) )[1]
+    for( i in 1:length( in.files ) ){
+      gi <- gregexpr( "GID[0-9]+", in.files[i], extract=T )
+      rname <- paste( gi, "_vs_", db.name, ".txt", sep="" )
+      res.files <- dir( out.folder )
+      if( !(rname %in% res.files) ){
+        if( verbose ) cat( "hmmerScan: Scanning", in.files[i], "...\n" )
+        command <- paste( basic, "--domtblout", file.path( out.folder, rname ), db, in.files[i]  )
+        system( command )
+        file.remove( log.fil )
+      }
     }
   }
 }
@@ -116,9 +133,11 @@ hmmerScan <- function( in.files, db, out.folder, threads=0, verbose=TRUE ){
 #' 
 #' @seealso \code{\link{hmmerScan}}, \code{\link{hmmerCleanOverlap}}, \code{\link{dClust}}.
 #' 
-#' @examples # See the example in the Help-file for dClust
+#' @examples
+#' # See the examples in the Help-files for dClust and hmmerScan.
+#' 
+#' @export readHmmer
 #' 
-#' @export
 readHmmer <- function( hmmer.file, e.value=1, use.acc=TRUE ){
   al <- readLines( hmmer.file )
   al <- al[which( !grepl( "\\#", al ) )]
@@ -135,7 +154,14 @@ readHmmer <- function( hmmer.file, e.value=1, use.acc=TRUE ){
   start <- as.numeric( sapply( lst, function(x){ x[18] } ) )
   stopp <- as.numeric( sapply( lst, function(x){ x[19] } ) )
   desc <- sapply( lst, function(x){ paste( x[23:length( x )], collapse=" " ) } )
-  hmmer.table <- data.frame( Query=query, Hit=hit, Evalue=ievalue, Score=score, Start=start, Stop=stopp, Description=desc, stringsAsFactors=F )
+  hmmer.table <- data.frame( Query=query,
+                             Hit=hit,
+                             Evalue=ievalue,
+                             Score=score,
+                             Start=start,
+                             Stop=stopp,
+                             Description=desc,
+                             stringsAsFactors=F )
   hmmer.table <- hmmer.table[which( hmmer.table$Evalue <= e.value ),]
   return( hmmer.table )
 }
